@@ -24,10 +24,7 @@ class Entity(object):
     def _get_relevant_data(self):
         data = {}
         for k in self.schema.keys():
-            try:
-                data[k] = self._data[k] 
-            except KeyError:
-                pass
+            data[k] = self._data[k] 
 
         return data
 
